Page 13 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 13

Home

    totally secure.
    Scripture records that during a feast for a thousand of
    his lords, King Belshazzar called for the vessels that

    Nebuchadnezzar had taken out of the temple in
    Jerusalem. At the very hour when the king and his guests
    drank out of the sacred vessels and praised their gods,

    the fingers of a man's hand appeared and wrote a
    message upon the plaster of the palace wall. It was a
    message announcing that God had decreed an end to the
    Babylonian kingdom. The entire story is related in Daniel
    chapter 5, drawing the curtain down in verses 30 and 31:

    In that night was Belshazzar king of the Chaldeans slain.
    And Darius the Median took the kingdom, being about
    three score and two years old.

    What had taken place, as recorded by ancient
    historians, is related in Halley's Bible Handbook:

    The Fall of Babylon is thus related by Xenophon,
    Herodotus and Berosus: "Cyrus diverted the Euphrates
    into a new channel, and guided by two deserters,
    marched by the dry bed into the city, while the
    Babylonians were carousing at a feast of their gods."!

    Babylon, as prophesied by Isaiah a hundred years before
    it rose to the zenith of its power, is nothing more than a

    The Secret Side of History

    came very suddenly during a time when her leaders felt

    Nebuchadnezzar had

    The city fell without a battle; and today Ancient